==> apache-ignite-2.6.0-src.zip: apache-ignite-2.6.0-src/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/Cache/EmptyObject.cs <==
﻿/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Core.Tests.Client.Cache
{
    using System;
    using System.Runtime.Serialization;
    using NUnit.Framework;

    /// <summary>
    /// Object with no fields.
    /// </summary>
    [Serializable]
    public class EmptyObject : ISerializable
    {
        /// <summary>
        /// Initializes a new instance of the EmptyObject class.
        /// </summary>
        public EmptyObject()
        {
            // No-op.
        }

        /// <summary>
        /// Initializes a new instance of the EmptyObject class.
        /// </summary>
        private EmptyObject(SerializationInfo info, StreamingContext context)
        {
            Assert.AreEqual(StreamingContextStates.All, context.State);
            Assert.IsNull(context.Context);
        }

        /** <inheritdoc /> */
        public void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            Assert.AreEqual(StreamingContextStates.All, context.State);
            Assert.IsNull(context.Context);
        }
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/platforms/dotnet/Apache.Ignite.Core.Tests/Client/Cache/EmptyObject.cs <==
﻿/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Core.Tests.Client.Cache
{
    using System;
    using System.Runtime.Serialization;
    using NUnit.Framework;

    /// <summary>
    /// Object with no fields.
    /// </summary>
    [Serializable]
    public sealed class EmptyObject : ISerializable
    {
        /// <summary>
        /// Initializes a new instance of the EmptyObject class.
        /// </summary>
        public EmptyObject()
        {
            // No-op.
        }

        /// <summary>
        /// Initializes a new instance of the EmptyObject class.
        /// </summary>
        private EmptyObject(SerializationInfo info, StreamingContext context)
        {
            Assert.AreEqual(StreamingContextStates.All, context.State);
            Assert.IsNull(context.Context);
        }

        /** <inheritdoc /> */
        public void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            Assert.AreEqual(StreamingContextStates.All, context.State);
            Assert.IsNull(context.Context);
        }
    }
}
